// Copyright 2015 The Rust Project Developers. See the COPYRIGHT
// file at the top-level directory of this distribution and at
// http://rust-lang.org/COPYRIGHT.
//
// Licensed under the Apache License, Version 2.0 <LICENSE-APACHE or
// http://www.apache.org/licenses/LICENSE-2.0> or the MIT license
// <LICENSE-MIT or http://opensource.org/licenses/MIT>, at your
// option. This file may not be copied, modified, or distributed
// except according to those terms.

struct TS ( //~ ERROR empty tuple structs and enum variants are not allowed
    #[cfg(untrue)]
    i32,
);

enum E {
    TV ( //~ ERROR empty tuple structs and enum variants are not allowed
        #[cfg(untrue)]
        i32,
    )
}

fn main() {
    let s = TS;
    let tv = E::TV;
}
